@@ -38,7 +38,7 @@ def main() -> None:
 
     if parser.json:
         print(console_output.to_json(retrieved_rss_content))
-    elif parser.pdf is None and parser.html is None:
+    elif parser.pdf is None and parser.html is None or parser.colorize:
         console_output.to_console(retrieved_rss_content, colorize=parser.colorize)
 
 
